@@ -45,6 +45,31 @@ EXTERNAL_PROJECTS = ("ROOT",)
 forced_paths = {}
 
 
+def force_paths_from_slot(slot_dir):
+    """
+    Define forced paths from a nightly build slot configuration in
+    the installation directory `slot_dir`.
+    """
+    import json
+
+    global forced_paths
+    try:
+        # force all projects in the slot to be used from the slot directory
+        slot_config = json.load(open(os.path.join(slot_dir, "slot-config.json")))
+        # first collect and then update to avoid partial updates due
+        # to malformed configuration
+        new_paths = list(
+            (project["name"], os.path.join(slot_dir, project["name"]))
+            for project in slot_config["projects"]
+            if not project.get("disabled")
+        )
+        forced_paths.update(new_paths)
+    except (KeyError, OSError, IOError, ValueError):
+        # FIXME: it should be `json.JSONDecodeError`, but `ValueError` is good enough for Python 2 and 3
+        # ignore invalid/missing/malformed configs
+        pass
+
+
 def platform_sort_key(platform):
     """
     Key function to sort platforms.
@@ -220,13 +245,11 @@ def findProject(name, version, platform, allow_empty_version=False):
     versions = [version]
 
     if re.match(r"^\d+\.\d+(\.\d+)*$", version):
-        # If we are requested to find a X.Y[.Z] version (new style CMake config)
-        # we have to look also for directories with vXrY[pZ]
+        # If we are requested to find a X.Y[.Z[.T]] version (new style CMake config)
+        # we have to look also for directories with vXrY[pZ[tN]]
         parts = version.split(".")
-        if len(parts) == 2:
-            versions.append("v{}r{}".format(*parts))
-        elif len(parts) == 3:
-            versions.append("v{}r{}p{}".format(*parts))
+        if len(parts) in [2, 3, 4]:
+            versions.append("".join("{}{}".format(a, b) for a, b in zip("vrpt", parts)))
         else:
             pass  # we have a convention only for 2 or 3 parts versions
 
