@@ -31,8 +31,8 @@ elif os_id().endswith("centos7"):
     CAN_RUN_NATIVE_CENTOS7 = True
 elif os_id().endswith("centos8"):
     CAN_RUN_NATIVE_SLC5 = False
-    CAN_RUN_NATIVE_SLC6 = True
-    CAN_RUN_NATIVE_CENTOS7 = True
+    CAN_RUN_NATIVE_SLC6 = False
+    CAN_RUN_NATIVE_CENTOS7 = False
 else:
     CAN_RUN_NATIVE_SLC5 = False
     CAN_RUN_NATIVE_SLC6 = False
@@ -93,7 +93,7 @@ def test_setupproject():
     try:
         output, used_container = _check_gaudirun(["--disallow-containers"] + command)
     except CalledProcessError:
-        assert not CAN_RUN_NATIVE_SLC5, output
+        assert not CAN_RUN_NATIVE_SLC5
     else:
         assert CAN_RUN_NATIVE_SLC5, output
 
@@ -117,7 +117,7 @@ def test_setupproject_best():
     try:
         output, used_container = _check_gaudirun(["--disallow-containers"] + command)
     except CalledProcessError:
-        assert not CAN_RUN_NATIVE_SLC5, output
+        assert not CAN_RUN_NATIVE_SLC5
     else:
         assert CAN_RUN_NATIVE_SLC5, output
         assert not used_container, output
@@ -142,7 +142,7 @@ def test_lbrun_slc6():
     try:
         output, used_container = _check_gaudirun(["--disallow-containers"] + command)
     except CalledProcessError:
-        assert not CAN_RUN_NATIVE_SLC6, output
+        assert not CAN_RUN_NATIVE_SLC6
     else:
         assert CAN_RUN_NATIVE_SLC6, output
         assert not used_container, output
@@ -167,7 +167,7 @@ def test_lbrun_centos7():
     try:
         output, used_container = _check_gaudirun(["--disallow-containers"] + command)
     except CalledProcessError:
-        assert not CAN_RUN_NATIVE_CENTOS7, output
+        assert not CAN_RUN_NATIVE_CENTOS7
     else:
         assert CAN_RUN_NATIVE_CENTOS7, output
         assert not used_container, output
@@ -192,7 +192,7 @@ def test_lbrun_best():
     try:
         output, used_container = _check_gaudirun(["--disallow-containers"] + command)
     except CalledProcessError:
-        assert not (CAN_RUN_NATIVE_SLC6 or CAN_RUN_NATIVE_CENTOS7), output
+        assert not (CAN_RUN_NATIVE_SLC6 or CAN_RUN_NATIVE_CENTOS7)
     else:
         assert CAN_RUN_NATIVE_SLC6 or CAN_RUN_NATIVE_CENTOS7, output
         assert not used_container, output
